@@ -34,10 +34,22 @@ class HumanReadableTextFormatting:
         if method == 'dollar-short':
             return f'${cls._longnum2string(x)}'
         if method == 'percent':
-            return f'{round(x*1000)/10}%'
+            return f'{cls._decimal2percent(x)}%'
         if method == 'inflect':
             return inflect.engine().number_to_words(x)
 
+    @staticmethod
+    def _decimal2percent(x):
+        if x == 0:
+            return 0
+        n_digits = np.max((np.floor(-np.log10(x)), 0))
+        m1 = 10**(2 + n_digits)
+        m2 = 10**(n_digits)
+        pct = round(x*m1)/m2
+        if n_digits == 0:
+            pct = round(pct)
+        return pct
+
     @staticmethod
     def _longnum2string(x):
         units = ['', 'K', 'M', 'G', 'T', 'P']
@@ -87,14 +99,13 @@ def distlr_fig_formatting(fig):
             '#838D9C',
             '#05152D'
         ],
-        'fig_width': 268,
-        'fig_height': 225,
+        'fig_width': 282,
+        'fig_height': 260,
         'axis_font_size': 10,
         'data_label_font_size': 12,
         'titlefont_size': 12
     }
 
-    print('NEW FORMATTING!!!!')
     format_fig_layout(fig, fig_params)
 
     axes_updates(fig, fig_params)
@@ -112,9 +123,9 @@ def format_fig_layout(fig, fig_params):
 
     # adjust fig height based on number of figures
     # .75 fig_height for every fig greater than 1
-    fig_height = 225
+    fig_height = fig_params['fig_height']
     fig_height = n_rows * fig_height + (n_rows-1)*.5 * fig_height
-    fig_width = 282
+    fig_width = fig_params['fig_width']
 
     fig.update_layout(
         titlefont_size=12,
@@ -237,6 +248,7 @@ def update_yaxis_from_dict(fig, trace_dict):
             fig.update_yaxes(
                 selector=vals['selector'],
                 tickmode='array',
+
                 tickvals=tick_steps[1:],
                 range=[ymin, ymax],
             )
